/* xpm.h
 *
 * Copyright (c) 1998-2002  Mike Oliphant <oliphant@gtk.org>
 *
 *   http://www.nostatic.org/grip
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
 * USA
 */

#include "../pixmaps/check.xpm"
#include "../pixmaps/discdb0.xpm"
#include "../pixmaps/discdb1.xpm"
#include "../pixmaps/eject.xpm"
#include "../pixmaps/cdscan.xpm"
#include "../pixmaps/ff.xpm"
#include "../pixmaps/lowleft.xpm"
#include "../pixmaps/lowright.xpm"
#include "../pixmaps/minmax.xpm"
#include "../pixmaps/nexttrk.xpm"
#include "../pixmaps/playpaus.xpm"
#include "../pixmaps/prevtrk.xpm"
#include "../pixmaps/loop.xpm"
#include "../pixmaps/noloop.xpm"
#include "../pixmaps/random.xpm"
#include "../pixmaps/playlist.xpm"
#include "../pixmaps/playnorm.xpm"
#include "../pixmaps/quit.xpm"
#include "../pixmaps/rew.xpm"
#include "../pixmaps/stop.xpm"
#include "../pixmaps/upleft.xpm"
#include "../pixmaps/upright.xpm"
#include "../pixmaps/vol.xpm"
#include "../pixmaps/discdbwht.xpm"
#include "../pixmaps/rotate.xpm"
#include "../pixmaps/edit.xpm"
#include "../pixmaps/progtrack.xpm"
#include "../pixmaps/mail.xpm"
#include "../pixmaps/save.xpm"

#include "../pixmaps/grip.xpm"
#include "../pixmaps/enc0.xpm"
#include "../pixmaps/enc1.xpm"
#include "../pixmaps/enc2.xpm"
#include "../pixmaps/enc3.xpm"
#include "../pixmaps/rip0.xpm"
#include "../pixmaps/rip1.xpm"
#include "../pixmaps/rip2.xpm"
#include "../pixmaps/rip3.xpm"
#include "../pixmaps/smile1.xpm"
#include "../pixmaps/smile2.xpm"
#include "../pixmaps/smile3.xpm"
#include "../pixmaps/smile4.xpm"
#include "../pixmaps/smile5.xpm"
#include "../pixmaps/smile6.xpm"
#include "../pixmaps/smile7.xpm"
#include "../pixmaps/smile8.xpm"
